GWAccount class
Properties
- address → String
-
Account's address.
final
-
auth
→ Map<
String, String> -
no setter
- createdAt → DateTime
-
Account creation date
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
Account's id.
final
- isDeleted ↔ bool
-
Whenever the account is deleted.
getter/setter pair
- isDisabled ↔ bool
-
Whether the account is active or not.
getter/setter pair
-
messages
→ Stream<
GWMessage> -
A stream of GWMessage
no setter
- password → String
-
Account's password.
final
- quota ↔ int
-
Account's quota (To store message data).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt ↔ DateTime
-
Account update date
getter/setter pair
- used ↔ int
-
Account's quota used.
getter/setter pair
Methods
-
delete(
) → Future< bool> - Deletes the account Be careful to not use an account after it is been deleted
-
getAllMessages(
) → Future< List< GWMessage> > - Returns all the account's messages
-
getMessages(
[int page = 1]) → Future< List< GWMessage> > - Returns one page the account's messages (30 per page)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
-
update(
) → Future< GWAccount> - Updates the account instance and returns it
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override